#
# spec file for package jemmy
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2000-2010, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __jar_repack %{nil}
# Install time macros
%global target_jar build/%{name}.jar
%global target_javadoc build/javadoc/*
Name:           jemmy
Version:        2.3.0.0
Release:        27.4
Summary:        Java UI testing library
License:        CDDL-1.0 OR GPL-2.0-only
Group:          Development/Libraries/Java
URL:            https://jemmy.dev.java.net
# The source for this package was pulled from upstream's vcs.  Use the
# following commands to generate the tarball:
#
# svn export https://jemmy.dev.java.net/svn/jemmy/trunk/Jemmy2 jemmy-2.3.0.0 --username <username>
# tar -czvf jemmy-2.3.0.0.tar.gz jemmy-2.3.0.0
#
# where <username> is a name of the user registered here: https://www.dev.java.net/servlets/Join
Source0:        jemmy-2.3.0.0.tar.bz2
Source1:        jemmy-2.3.0.0.pom
Patch0:         jemmy-nosource.patch
BuildRequires:  ant >= 1.6.5
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
Requires:       java >= 1.8
Requires:       javapackages-tools
BuildArch:      noarch

%description
Jemmy is a Java UI testing library. Jemmy represents the most natural way to
test Java UI - perform the testing right from the Java code. Jemmy is a Java
library which provides clear and straightforward API to access Java UI. Tests
are then just java programs, which use the API. Having the tests in Java allows
to use all the flexibility of high level language to capture test logic and
also do any other operations needed to be done from test.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation/HTML
Requires:       %{name} = %{version}
Requires:       javapackages-tools

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
%patch -P 0 -p1
find . -type f -name '*.jar' | xargs -t rm
echo "Please, visit https://jemmy.dev.java.net for more info about Jemmy." > README.txt

%build
ant -Dant.build.javac.source=1.8 -Dant.build.javac.target=1.8 jar javadoc

%install
# jar
mkdir -p %{buildroot}%{_javadir}
cp -a %{target_jar} %{buildroot}%{_javadir}/%{name}.jar

install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -a %{target_javadoc} %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%doc README.txt

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Mon Sep 18 2017 fstrba@suse.com
- Fix build with jdk9: specify java source and target 1.6
- Added patch:
  * jemmy-nosource.patch
    + Don't hardcode java source so that it can be specified from
    ant's build command-line
* Fri May 19 2017 mpluskal@suse.com
- Update dependencies
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Jun 27 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Build on SLE11
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Mar  7 2013 cfarrell@suse.com
- license update: GPL-2.0 or CDDL-1.0
  previous spec file license made no sense
* Tue Mar  5 2013 coolo@suse.com
- update license to new format
* Sun Dec 19 2010 andreas.hanke@gmx-topmail.de
- fix dependency to make -javadoc package installable
* Thu Apr  8 2010 mvyskocil@suse.cz
- fix bnc#594443 - fix the license to CCDL or CCDL;GPLv2
* Thu Mar 25 2010 mvyskocil@suse.cz
- Initial SUSE packaging
  jemmy-2.3.0.0-5.jpp6.src.rpm
